@@ -1,15 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Types;
 
 use DateTime;
-use DateTimeInterface;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-
-use function date_create;
+use Doctrine\DBAL\Types\Exception\ValueNotConvertible;
+use Exception;
 
 /**
- * Variable DateTime Type using date_create() instead of DateTime::createFromFormat().
+ * Variable DateTime Type using DateTime::__construct() instead of DateTime::createFromFormat().
  *
  * This type has performance implications as it runs twice as long as the regular
  * {@see DateTimeType}, however in certain PostgreSQL configurations with
@@ -18,25 +19,24 @@ use function date_create;
 class VarDateTimeType extends DateTimeType
 {
     /**
-     * {@inheritdoc}
-     *
      * @param T $value
      *
-     * @return (T is null ? null : DateTimeInterface)
+     * @return (T is null ? null : DateTime)
      *
      * @template T
      */
-    public function convertToPHPValue($value, AbstractPlatform $platform)
+    public function convertToPHPValue(mixed $value, AbstractPlatform $platform): ?DateTime
     {
         if ($value === null || $value instanceof DateTime) {
             return $value;
         }
 
-        $val = date_create($value);
-        if ($val === false) {
-            throw ConversionException::conversionFailed($value, $this->getName());
+        try {
+            $dateTime = new DateTime($value);
+        } catch (Exception $e) {
+            throw ValueNotConvertible::new($value, DateTime::class, $e->getMessage(), $e);
         }
 
-        return $val;
+        return $dateTime;
     }
 }
