@@ -1,13 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\Middleware;
 
 use Doctrine\DBAL\Driver\Connection;
 use Doctrine\DBAL\Driver\Middleware\AbstractConnectionMiddleware;
 use Doctrine\DBAL\Driver\Result;
-use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
 use Doctrine\DBAL\Driver\Statement;
-use LogicException;
 use PHPUnit\Framework\TestCase;
 
 final class AbstractConnectionMiddlewareTest extends TestCase
@@ -52,7 +52,7 @@ final class AbstractConnectionMiddlewareTest extends TestCase
 
     public function testGetServerVersion(): void
     {
-        $connection = $this->createMock(ServerInfoAwareConnection::class);
+        $connection = $this->createMock(Connection::class);
         $connection->expects(self::once())
             ->method('getServerVersion')
             ->willReturn('1.2.3');
@@ -60,45 +60,21 @@ final class AbstractConnectionMiddlewareTest extends TestCase
         self::assertSame('1.2.3', $this->createMiddleware($connection)->getServerVersion());
     }
 
-    public function testGetServerVersionFailsOnLegacyConnections(): void
-    {
-        $connection = $this->createMock(Connection::class);
-        $middleware = $this->createMiddleware($connection);
-
-        $this->expectException(LogicException::class);
-        $middleware->getServerVersion();
-    }
-
     public function testGetNativeConnection(): void
     {
         $nativeConnection = new class () {
         };
 
-        $connection = $this->createMock(NativeDriverConnection::class);
+        $connection = $this->createMock(Connection::class);
         $connection->method('getNativeConnection')
             ->willReturn($nativeConnection);
 
         self::assertSame($nativeConnection, $this->createMiddleware($connection)->getNativeConnection());
     }
 
-    public function testGetNativeConnectionFailsWithLegacyConnection(): void
-    {
-        $connection = $this->createMock(Connection::class);
-        $middleware = $this->createMiddleware($connection);
-
-        $this->expectException(LogicException::class);
-        $middleware->getNativeConnection();
-    }
-
     private function createMiddleware(Connection $connection): AbstractConnectionMiddleware
     {
         return new class ($connection) extends AbstractConnectionMiddleware {
         };
     }
 }
-
-interface NativeDriverConnection extends ServerInfoAwareConnection
-{
-    /** @return object|resource */
-    public function getNativeConnection();
-}
