@@ -1,19 +1,22 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\PDO;
 
 use Doctrine\DBAL\Driver\PDO\Exception;
 use PDOException;
+use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\TestCase;
 
-/** @requires extension pdo */
+#[RequiresPhpExtension('pdo')]
 class ExceptionTest extends TestCase
 {
-    public const ERROR_CODE = 666;
+    private const ERROR_CODE = 666;
 
-    public const MESSAGE = 'PDO Exception';
+    private const MESSAGE = 'PDO Exception';
 
-    public const SQLSTATE = 'HY000';
+    private const SQLSTATE = 'HY000';
 
     /**
      * The PDO exception wrapper under test.
