@@ -8,8 +8,10 @@ use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\LockMode;
-use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
@@ -33,9 +35,20 @@ class NoneTest extends FunctionalTestCase
             $this->connection->executeStatement('ALTER DATABASE ' . $db . ' SET MULTI_USER');
         }
 
-        $table = new Table('users');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('users')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
@@ -47,11 +60,11 @@ class NoneTest extends FunctionalTestCase
 
         $this->connection2 = DriverManager::getConnection($params);
 
-        if ($this->connection2->getSchemaManager()->tablesExist('users')) {
+        if ($this->connection2->createSchemaManager()->tableExists('users')) {
             return;
         }
 
-        if ($this->connection2->getDatabasePlatform() instanceof SqlitePlatform) {
+        if ($this->connection2->getDatabasePlatform() instanceof SQLitePlatform) {
             self::markTestSkipped('This test cannot run on SQLite using an in-memory database');
         }
 
@@ -62,16 +75,19 @@ class NoneTest extends FunctionalTestCase
     {
         $this->connection2->close();
 
-        if (! $this->connection->getDatabasePlatform() instanceof SQLServerPlatform) {
-            return;
-        }
+        $this->connection->createSchemaManager()->dropTable('users');
 
-        if ($this->connection->isTransactionActive()) {
+        if ($this->connection->getDatabasePlatform() instanceof SQLServerPlatform) {
             $this->connection->rollBack();
+
+            $db = $this->connection->getDatabase();
+            $this->connection->executeStatement('ALTER DATABASE ' . $db . ' SET READ_COMMITTED_SNAPSHOT OFF');
         }
 
-        $db = $this->connection->getDatabase();
-        $this->connection->executeStatement('ALTER DATABASE ' . $db . ' SET READ_COMMITTED_SNAPSHOT OFF');
+        // depending on current database platform, the above DROP TABLE may or may not commit the transaction,
+        // and there's no way to see whether the transaction is active. so we're closing the connection explicitly
+        // to avoid the ROLLBACK failure in {@link disconnect()}
+        $this->connection->close();
     }
 
     public function testLockModeNoneDoesNotBreakTransactionIsolation(): void
@@ -79,7 +95,7 @@ class NoneTest extends FunctionalTestCase
         try {
             $this->connection->setTransactionIsolation(TransactionIsolationLevel::READ_COMMITTED);
             $this->connection2->setTransactionIsolation(TransactionIsolationLevel::READ_COMMITTED);
-        } catch (Exception $e) {
+        } catch (Exception) {
             self::markTestSkipped('This test must be able to set a transaction isolation level');
         }
 
